{% extends "account/base.html" %}

{% load i18n %}
{% load crispy_forms_tags %}

{% block head_title %}{% trans "Change Password" %}{% endblock head_title %}

{% block inner %}
    <h1>{% trans "Change Password" %}</h1>

    <form method="POST" action="{% url 'account_change_password' %}" class="password_change">
        {% csrf_token %}
        {{ form|crispy }}
        <button class="btn btn-primary" type="submit" name="action">{% trans "Change Password" %}</button>
    </form>
{% endblock %}

